# FG Finder
A python package to identfy functional groups in molecules.

# How to install
### Pip
```
pip install FGFinder
```

### Manual
```
git clone https://github.com/Borest5543/Fg_Finder
cd Fg_Finder
python setup.py install
``` 
